@@ -2,7 +2,8 @@ from typing import Dict, Type, Union
 
 from rest_framework import serializers
 
-from pipeline_views.serializers import DetailSerializer
+from .serializers import DetailSerializer
+from .typing import HTTPMethod
 
 
 __all__ = [
@@ -10,8 +11,6 @@ __all__ = [
     "PipelineSchemaMixin",
 ]
 
-from pipeline_views.typing import HTTPMethod
-
 
 def add_default_response(responses):
     if ... not in set(responses.values()):
